@@ -36,11 +36,11 @@ AbstractPreferences.includeBasePath = includeBasePath;
 AbstractPreferences.prototype.beginEvent = function() {
     Edit.prototype.beginEvent.call(this);
     
-    this.dialog = this.createWidget(AbstractPreferences.includeBasePath + "/AbstractPreferences.ui");
+    this.dialog = this.createDialog(AbstractPreferences.includeBasePath + "/AbstractPreferences.ui");
     // TODO: Qt 5: add this flag (?)
     //var flags = new Qt.WindowFlags(Qt.WindowTitleHint);
     //this.dialog.setWindowFlags(flags);
-    this.treeWidget = this.dialog.findChild("twCategory");
+    this.treeWidget = this.dialog.findChild("Category");
     var title;
     if (this.appPreferences) {
         title = qsTr("Application Preferences");
@@ -49,9 +49,9 @@ AbstractPreferences.prototype.beginEvent = function() {
     }
     this.dialog.setWindowTitle(title);
     this.treeWidget.setHeaderLabel(title);
-    this.pageWidget = this.dialog.findChild("stwPage");
-    this.filterWidget = this.dialog.findChild("leFilter");
-    this.titleWidget = this.dialog.findChild("lbTitle");
+    this.pageWidget = this.dialog.findChild("Page");
+    this.filterWidget = this.dialog.findChild("Filter");
+    this.titleWidget = this.dialog.findChild("Title");
     
     var splitter = this.dialog.findChild("splitter");
     splitter.setStretchFactor(0, 1);
@@ -61,7 +61,7 @@ AbstractPreferences.prototype.beginEvent = function() {
     this.treeWidget.itemSelectionChanged.connect(this, this.showPage);
     this.filterWidget.textChanged.connect(this, this.filterTree);
 
-    var btApply = this.dialog.findChild("buttonBox").button(QDialogButtonBox.Apply);
+    var btApply = this.dialog.findChild("ButtonBox").button(QDialogButtonBox.Apply);
     btApply.clicked.connect(this, this.apply);
 
     this.addOns = AddOn.getAddOns();
@@ -73,6 +73,8 @@ AbstractPreferences.prototype.beginEvent = function() {
         this.showPageFor(this.initialClassName);
     }
 
+    this.filterWidget.setFocus();
+
     if (this.dialog.exec() === QDialog.Accepted.valueOf()) {
         // apply calls save and apply:
         this.apply();
@@ -87,6 +89,11 @@ AbstractPreferences.prototype.beginEvent = function() {
  * Initializes the navigation tree based on available add-ons with preferences.
  */
 AbstractPreferences.fillTreeWidget = function(addOns, treeWidget, appPreferences) {
+
+    var appWin = EAction.getMainWindow();
+    var defaultPage = appWin.property("PreferencesPage");
+    appWin.setProperty("PreferencesPage", "");
+
     for (var i = 0; i < addOns.length; ++i) {
         var addOn = addOns[i];
         var className = addOn.getClassName();
@@ -108,7 +115,8 @@ AbstractPreferences.fillTreeWidget = function(addOns, treeWidget, appPreferences
                 include(addOn.getFilePath());
             }
         } catch (e1) {
-            qWarning("AppPreferences.js: Exception: ", e1);
+            qWarning("AbstractPreferences.js: exception: ", e1);
+            qWarning("AbstractPreferences.js: file: ", addOn.getFilePath());
             continue;
         }
         var cat;
@@ -121,7 +129,7 @@ AbstractPreferences.fillTreeWidget = function(addOns, treeWidget, appPreferences
                 continue;
             }
         } catch (e2) {
-            qWarning("AppPreferences.js: Add-on class not found: ", className, " exception: ", e2);
+            qWarning("AbstractPreferences.js: add-on class not found: ", className, " exception: ", e2);
             continue;
         }
         
@@ -144,23 +152,28 @@ AbstractPreferences.fillTreeWidget = function(addOns, treeWidget, appPreferences
         }
         var parent = item;
         for (var x = 1; x < cat.length; ++x) {
-            var subitem;
-            subitem = undefined;
+            var subItem;
+            subItem = undefined;
             for (var c = 0; c < parent.childCount(); ++c) {
                 var child = parent.child(c);
                 if (child.text(0) === cat[x]) {
-                    subitem = child;
+                    subItem = child;
                     break;
                 }
             }
-            if (isNull(subitem)) {
-                subitem = new QTreeWidgetItem(parent, [ cat[x] ]);
-                parent.addChild(subitem);
+            if (isNull(subItem)) {
+                subItem = new QTreeWidgetItem(parent, [ cat[x] ]);
+                parent.addChild(subItem);
                 if (x == cat.length - 1) {
-                    subitem.setData(0, Qt.UserRole, i);
+                    subItem.setData(0, Qt.UserRole, i);
+
+                    // select a default page:
+                    if (className===defaultPage) {
+                        subItem.setSelected(true);
+                    }
                 }
             }
-            parent = subitem;
+            parent = subItem;
         }
     }
     treeWidget.sortItems(0, Qt.AscendingOrder);
@@ -387,10 +400,13 @@ AbstractPreferences.prototype.save = function() {
                 }
             }
             if (!isNull(document) && preferencesScope==="block") {
+                // saving to block:
                 store = document.queryCurrentBlock();
             }
         }
+
         WidgetFactory.saveState(widget, undefined, store);
+
         if (!this.appPreferences) {
             if (preferencesScope==="block") {
                 transaction.addObject(store);
